@@ -2,6 +2,14 @@
 # wrapper for various auto- and cross-distance functions.
 # mostly compatible with dist.
 #
+# note that some of the checks may be unecessary, but we 
+# cannot rely on R implementation details. what a mess!
+#
+# fixme: storage mode coerces which may be inappropriate.
+#        we should raise an error if this would result in
+#        a narrowing conversions, so that the user can
+#        decide what she wants.
+#
 # (C) ceeboo 2005
 
 dists <- function(x, y=NULL, method="minkowski", p=2) {
@@ -65,30 +73,77 @@ dists <- function(x, y=NULL, method="minkowski", p=2) {
 # subsetting for objects of class dist. 
 # 
 # note that non-unique indexing is allowed but will return
-# NAs for some entries because we usually do not have the
-# diagonal entries.
+# NAs for some entries because we do not have diagonal 
+# entries. fixed NA subscripts.
 #
-# ceeboo 2005
+# fixme: coercing to double is conceptually not quite 
+#        correct but not trivial to implement otherwise.
+#
+# ceeboo 2005, 2006
 
 subset.dist <- function(x, subset, ...) {
     if (missing(subset))
        return(x)
-    if (attr(x, "Diag"))		    # rare, so forget about it
-       stop("diagonal not implemented")
     # subscript hack
     labels <- array(1:attr(x, "Size"))
     rownames(labels) <- attr(x, "Labels")
     if (!is.double(x))
        storage.mode(x) <- "double"
-    # sets the Labels attribute
+    # sets Size and Labels
     obj <- .Call("subset_dist", x, subset, labels)
-    obj <-  structure(obj, Size=length(subset), class="dist", 
-                      Diag=FALSE, Upper=attr(x, "Upper"), 
-                      method=attr(x, "method"))
+    obj <- structure(obj, class="dist", 
+                          Diag=attr(x, "Diag"), Upper=attr(x, "Upper"), 
+                          method=attr(x, "method"))
     obj
 }
 
 "[[.dist" <- subset.dist
 
+rowSums.dist <- colSums.dist <- function(x, na.rm = FALSE) {
+    if (!inherits(x, "dist"))
+        stop("'x' not of class 'dist'")
+    storage.mode(x) <- "real"
+    if (!is.logical(na.rm))
+        stop("'na.rm' not logical")
+    obj <- .Call("rowSums_dist", x, na.rm)
+    names(obj) <- attr(x, "Labels")
+    obj
+}
+
+dapply <- function(x, y = NULL, FUN, ...) {
+    if (!is.matrix(x))
+        stop(gettext("'x' not a matrix"))
+    storage.mode(x) <- "real"
+    if (!is.null(y)) {
+        if (!is.matrix(y))
+            stop(gettext("'y' not a matrix"))
+        if (dim(x)[2] != dim(y)[2])
+            stop(gettext("'x' and 'y' do not conform"))
+        storage.mode(y) <- "real"
+    }
+    if (!is.function(FUN))
+        stop("'FUN' not a function")
+    obj <- .External("apply_dist", x, y, FUN, ...)
+    if (!is.null(y)) {
+        rownames(obj) <- rownames(x)
+        colnames(obj) <- rownames(y)
+    } else 
+        obj <- structure(obj, Size=dim(x)[1], class="dist",
+                              Diag=FALSE, Upper=FALSE,
+                              Labels=rownames(x))
+    obj
+}
+
+##
+
+cluster.dist <- function(x, beta) {
+    if (!inherits(x, "dist"))
+        stop("'x' not of class dist")
+    storage.mode(x) <- storage.mode(beta) <- "real"
+    obj <- .Call("cluster_dist", x, beta)
+    names(obj) <- attr(x,"Labels")
+    obj
+}
+
 ###
 
